# Privacy note

git-annex-remote-googledrive is an application which is solely run on the user's machine. It provides an interface for [git-annex](https://git-annex.branchable.com/) in order to use Google Drive as remote for a git-annex repository. Files are transmitted directly to Google Drive and don't go through any other servers. git-annex-remote-googledrive never attempts any connection other than those with Google Drive API.
